@@ -34,6 +34,9 @@ stringprep_find_character_in_table (uint32_t ucs4,
 {
   ssize_t i;
 
+  /* During self tests, this is where it spends its CPU time and
+     causes most cache misses.  Do a binary search? */
+
   for (i = 0; table[i].start; i++)
     if (ucs4 >= table[i].start &&
 	ucs4 <= (table[i].end ? table[i].end : table[i].start))
@@ -377,21 +380,20 @@ stringprep (char *in,
     }
 
   utf8 = stringprep_ucs4_to_utf8 (ucs4, ucs4len, 0, 0);
+  free (ucs4);
   if (!utf8)
-    {
-      free (ucs4);
-      return STRINGPREP_MALLOC_ERROR;
-    }
+    return STRINGPREP_MALLOC_ERROR;
 
   if (strlen (utf8) >= maxlen)
     {
       free (utf8);
-      free (ucs4);
       return STRINGPREP_TOO_SMALL_BUFFER;
     }
 
   strcpy (in, utf8);		/* flawfinder: ignore */
 
+  free (utf8);
+
   return STRINGPREP_OK;
 }
 
