@@ -33,11 +33,11 @@
 
 #include "idn_cmd.h"
 
-#define GREETING "Copyright 2002, 2003 Simon Josefsson.\n"\
-	"GNU Libidn comes with NO WARRANTY, to the extent permitted by law.\n"\
-	"You may redistribute copies of GNU Libidn under the terms of\n"\
-	"the GNU Lesser General Public License.  For more information\n"\
-	"about these matters, see the file named COPYING.LIB.\n"\
+#define GREETING "Copyright 2002, 2003 Simon Josefsson.\n"		\
+  "GNU Libidn comes with NO WARRANTY, to the extent permitted by law.\n" \
+  "You may redistribute copies of GNU Libidn under the terms of\n"	\
+  "the GNU Lesser General Public License.  For more information\n"	\
+  "about these matters, see the file named COPYING.LIB.\n"
 
 int
 main (int argc, char *argv[])
@@ -46,18 +46,25 @@ main (int argc, char *argv[])
   char readbuf[BUFSIZ];
   char *p, *r;
   uint32_t *q;
+  unsigned cmdn = 0;
   int rc;
 
   if (cmdline_parser (argc, argv, &args_info) != 0)
     return 1;
 
+  if (!args_info.stringprep_given &&
+      !args_info.punycode_encode_given && !args_info.punycode_decode_given &&
+      !args_info.idna_to_ascii_given && !args_info.idna_to_unicode_given)
+    args_info.idna_to_ascii_given = 1;
+
   if ((args_info.stringprep_given ? 1 : 0) +
       (args_info.punycode_encode_given ? 1 : 0) +
       (args_info.punycode_decode_given ? 1 : 0) +
       (args_info.idna_to_ascii_given ? 1 : 0) +
       (args_info.idna_to_unicode_given ? 1 : 0) != 1)
     {
-      fprintf (stderr, "%s: One of -s, -e, -d, -a or -u must be specified.\n",
+      fprintf (stderr,
+	       "%s: Only one of -s, -e, -d, -a or -u can be specified.\n",
 	       argv[0]);
       cmdline_parser_print_help ();
       return 1;
@@ -70,9 +77,18 @@ main (int argc, char *argv[])
     fprintf (stderr, "system locale uses charset `%s'.\n",
 	     stringprep_locale_charset ());
 
+  if (!args_info.quiet_given && args_info.inputs_num == 0)
+    fprintf (stderr, "Type each input string on a line by itself, "
+	     "terminated by a newline character.\n");
+
   do
     {
-      if (fgets (readbuf, BUFSIZ, stdin) == NULL)
+      if (cmdn < args_info.inputs_num)
+	{
+	  strncpy(readbuf, args_info.inputs[cmdn++], BUFSIZ - 1);
+	  readbuf[BUFSIZ-1] = '\0';
+	}
+      else if (fgets (readbuf, BUFSIZ, stdin) == NULL)
 	{
 	  sprintf (readbuf, "%s: fgets() failed: ", argv[0]);
 	  if (!feof (stdin))
@@ -384,7 +400,8 @@ main (int argc, char *argv[])
 	}
 
     }
-  while (!feof (stdin) && !ferror (stdin));
+  while (!feof (stdin) && !ferror (stdin) && (args_info.inputs_num == 0 ||
+					      cmdn < args_info.inputs_num));
 
   return 0;
 }
